pub(crate) struct StackSection {
pub(crate) inputs: u16,
pub(crate) max_growth: i16,
}Expand description
A stack section tracks stack height requirements for a sequence of instructions.
Stack sections end at instructions that require gasleft, branching instructions, or
suspending instructions. This keeps stack failures after dynamic-gas and host-effect
instructions from being hoisted ahead of those instructions.
Fields
inputs: u16The stack height required to execute the section.
max_growth: i16The maximum stack height growth relative to the stack height at section start.
Implementations
Sourceimpl StackSection
impl StackSection
Sourcepub(crate) fn from_stack_io(iter: impl IntoIterator<Item = (u8, u8)>) -> Self
pub(crate) fn from_stack_io(iter: impl IntoIterator<Item = (u8, u8)>) -> Self
Compute a stack section from an iterator of (inputs, outputs) pairs.